@@ -35,15 +35,18 @@ GUIMainwindow::GUIMainwindow()
 #endif
   VBox*     vbox     = new VBox;
   Notebook* notebook = new Notebook;
-  notebook->append_page(ipv4_analyzer,          _("IPv4 Address Analyzer"));
-  notebook->append_page(ipv4_subnet_calculator, _("IPv4 Subnet Calculator"));
-  notebook->append_page(ipv4_subnet_splitter,   _("IPv4 Subnet Cruncher"));
+  notebook->append_page(ipv4_analyzer,
+                        _("IPv4 Address Analyzer"));
+  notebook->append_page(ipv4_subnet_calculator,
+                        _("IPv4 Range to Prefix Converter"));
+  notebook->append_page(ipv4_subnet_splitter,
+                        _("IPv4 Subnet Calculator"));
   //notebook->set_border_width(12);
   vbox->pack_start(*manage(build_menu()), FALSE, FALSE);
   vbox->pack_start(*manage(notebook));
   vbox->show_all();
   add(*manage(vbox));
-  set_title(_("GIP - Internet Protocol Calculator"));
+  set_title(_("Internet Protocol Calculator"));
 }
 
 
